@@ -20,9 +20,29 @@
 #' \emph{Note} that `BiocCheck` is complementary to `R CMD check`.
 #' `R CMD check` should always be run first for best results.
 #'
-#' @section dot-options:
+#' To skip installation of the package during the check, set the
+#' `install` option to `FALSE` or `NULL`:
+#' \preformatted{
+#' BiocCheck(package, install=FALSE)
+#' ## OR
+#' BiocCheck(package, install=NULL)
+#' }
+#' To re-use an existing installation log file, set the `install` option
+#' to the name of the installation log file.
+#' For example, the following will put the `install_out.txt` log file in the
+#' `<package_name>.BiocCheck` directory:
+#' \preformatted{ BiocCheck(package, install="check:install_out.txt") }
 #'
-#'   * `build-output-file`: file containing R CMD build output, for
+#' @section dot-options:
+#' To use the dot-options, `BiocCheck` can be called with named arguments
+#' corresponding to the options below. Typically, these options are set to
+#' `TRUE` to disable specific checks, e.g.,
+#' \preformatted{ BiocCheck(package, `no-check-vignettes`=TRUE) }. Unless
+#' otherwise stated, these options can be left unset (i.e., `NULL`) to enable
+#' checks but `FALSE` can also be used to explicitly enable them. The available
+#' options are:
+#'
+#'   * `build-output-file`: file containing `R CMD build` output, for
 #'     additional analysis
 #'   * `new-package`:  enable checks specific to new packages
 #'   * `no-check-bbs`: disable BBS-specific checks (for non-BioC packages).
@@ -57,6 +77,13 @@
 #'   * `no-check-version-num`:  disable check for valid version number
 #'   * `no-check-vignettes`:  disable vignette checks
 #'   * `quit-with-status`:  enable exit code option when performing check
+#'   * `install`: if `FALSE`, the package is not installed; otherwise, if not
+#'     specified, the package is installed by default. Optionally, a
+#'     `check:<file>` key-value pair is provided to identify the name of the
+#'     installation output file which will be copied to the
+#'     `<package_name>.BiocCheck` directory.
+#'   * `libloc`: when `install` is specified, the library location where the
+#'     package is installed. By default, this is `.libPaths()[1]`.
 #'
 #' @param package The path to an R package directory or tarball (`.tar.gz`).
 #'   The `BiocCheck` function is intended to be run from the package
@@ -75,9 +102,7 @@
 #' @param callr logical(1) Whether to use the `callr` package to run `BiocCheck`
 #'   in an isolated R session to prevent namespace collisions.
 #'
-#' @param \dots See the details section for available options. When running
-#' `BiocCheck`, options can be specified as:
-#' \preformatted{ BiocCheck(package, `no-check-vignettes`=TRUE) }
+#' @param \dots See the `dot-options` details section for available options.
 #'
 #' @return `BiocCheck()` is chiefly called for the side effect of the check
 #'   reporting. The function also creates a `<package_name>.BiocCheck` folder
@@ -153,9 +178,32 @@ BiocCheckRun <-
     ## consider merging these operations into one
     cli::cli_div(theme = list(.pkg = list(color = "orange")))
     cli::cli_rule("Installing {.pkg { .BiocPackage$packageName }}")
-    package_install_dir <- installAndLoad(.BiocPackage)
-    cli::cli_alert_success("Package installed successfully")
-    libloc <- file.path(package_install_dir, "lib")
+
+    install_param <- dots[["install"]]
+    should_install <- is.null(install_param) || isTRUE(install_param)
+
+    if (should_install) {
+        package_install_dir <- .tryInstallwLoad(.BiocPackage)
+        cli::cli_alert_success("Package installed successfully")
+        libloc <- file.path(package_install_dir, "lib")
+    } else {
+        if (is.character(install_param)) {
+            split_log <- strsplit(install_param, ":")[[1L]]
+            inst_log <- utils::tail(split_log, n = 1L)
+            on.exit({
+                if (file.exists(inst_log))
+                    file.copy(
+                        from = inst_log,
+                        to = file.path(
+                            .BiocPackage$BiocCheckDir, basename(inst_log)
+                        )
+                    )
+            }, add = TRUE)
+        }
+        libloc <- dots[["libloc"]] %||% .libPaths()[1L]
+        package_install_dir <- .libPaths()[1L]
+    }
+
     isBBS <- Sys.getenv("IS_BIOC_BUILD_MACHINE")
     onBBS <- nzchar(isBBS) && identical(tolower(isBBS), "true")
     hasAdmin <- nzchar(Sys.getenv("BIOC_DEVEL_PASSWORD"))
@@ -168,12 +216,12 @@ BiocCheckRun <-
     cli::cli_rule("Running BiocCheck on {.pkg { .BiocPackage$packageName }}")
 
     # BiocCheck checks --------------------------------------------------------
-    if (is.null(dots[["no-check-deprecated"]])) {
+    if (.isNULLorFALSE(dots[["no-check-deprecated"]])) {
         handleCheck("Checking for deprecated package usage...")
         checkDeprecatedPackages(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-remotes"]])){
+    if (.isNULLorFALSE(dots[["no-check-remotes"]])){
         handleCheck("Checking for remote package usage...")
         checkRemotesUsage(.BiocPackage)
     }
@@ -181,28 +229,28 @@ BiocCheckRun <-
     handleCheck("Checking for 'LazyData: true' usage...")
     checkLazyDataUsage(.BiocPackage)
 
-    if (is.null(dots[["no-check-version-num"]])){
+    if (.isNULLorFALSE(dots[["no-check-version-num"]])){
         handleCheck("Checking version number...")
         if (!.BiocPackage$isSourceDir) {
             handleCheck("Checking for version number mismatch...")
             checkForVersionNumberMismatch(.BiocPackage)
         }
 
-        if (!is.null(dots[["new-package"]])) {
+        if (isTRUE(dots[["new-package"]])) {
             handleCheck("Checking new package version number...")
             checkNewPackageVersionNumber(.BiocPackage)
-        } else {
+        } else if (.isNULLorFALSE(dots[["new-package"]])) {
             handleCheck("Checking version number validity...")
             checkVersionNumber(.BiocPackage)
         }
     }
 
-    if (is.null(dots[["no-check-R-ver"]])) {
+    if (.isNULLorFALSE(dots[["no-check-R-ver"]])) {
         handleCheck("Checking R version dependency...")
         checkRVersionDependency(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-pkg-size"]])){
+    if (.isNULLorFALSE(dots[["no-check-pkg-size"]])){
         handleCheck("Checking package size...")
         if (.BiocPackage$isTar){
             checkPackageSize(.BiocPackage)
@@ -211,13 +259,13 @@ BiocCheckRun <-
         }
     }
 
-    if (is.null(dots[["no-check-file-size"]])){
+    if (.isNULLorFALSE(dots[["no-check-file-size"]])){
         handleCheck("Checking individual file sizes...")
         checkIndivFileSizes(.BiocPackage)
         checkDataFileSizes(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-bioc-views"]]))
+    if (.isNULLorFALSE(dots[["no-check-bioc-views"]]))
     {
         handleCheck("Checking biocViews...")
         result <- checkBiocViews(.BiocPackage)
@@ -229,16 +277,16 @@ BiocCheckRun <-
         }
     }
 
-    if (is.null(dots[["no-check-bbs"]])){
+    if (.isNULLorFALSE(dots[["no-check-bbs"]])){
         handleCheck("Checking build system compatibility...")
         checkBBScompatibility(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-description"]])) {
+    if (.isNULLorFALSE(dots[["no-check-description"]])) {
         checkDESCRIPTIONFile(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-namespace"]]))
+    if (.isNULLorFALSE(dots[["no-check-namespace"]]))
         checkNAMESPACE(.BiocPackage)
 
     handleCheck("Checking .Rbuildignore...")
@@ -252,7 +300,7 @@ BiocCheckRun <-
         checkInstDocFolder(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-vignettes"]])) {
+    if (.isNULLorFALSE(dots[["no-check-vignettes"]])) {
         handleCheck("Checking vignette directory...")
         checkVignetteDir(.BiocPackage)
         if ("build-output-file" %in% names(dots)) {
@@ -263,7 +311,7 @@ BiocCheckRun <-
         }
     }
 
-    if (is.null(dots[["no-check-library-calls"]])){
+    if (.isNULLorFALSE(dots[["no-check-library-calls"]])){
         handleCheck("Checking package installation calls in R code...")
         checkPkgInstallCalls(.BiocPackage)
     }
@@ -272,56 +320,56 @@ BiocCheckRun <-
     package_name <- .BiocPackage$packageName
     parsedCode <- parseFiles(.BiocPackage)
 
-    if (is.null(dots[["no-check-install-self"]])){
+    if (.isNULLorFALSE(dots[["no-check-install-self"]])){
         handleCheck(sprintf("Checking for library/require of %s...",
                             package_name))
         checkForLibraryRequire(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-coding-practices"]])){
+    if (.isNULLorFALSE(dots[["no-check-coding-practices"]])){
         handleCheck("Checking coding practice...")
         checkCodingPractice(.BiocPackage, parsedCode)
     }
 
-    if (is.null(dots[["no-check-function-len"]])){
+    if (.isNULLorFALSE(dots[["no-check-function-len"]])){
         handleCheck("Checking function lengths...")
         checkFunctionLengths(parsedCode, package_name)
     }
 
-    if (is.null(dots[["no-check-man-doc"]])){
+    if (.isNULLorFALSE(dots[["no-check-man-doc"]])){
         handleCheck("Checking man page documentation...")
         checkManDocumentation(.BiocPackage, libloc)
     }
 
-    if (is.null(dots[["no-check-news"]])){
+    if (.isNULLorFALSE(dots[["no-check-news"]])){
         handleCheck("Checking package NEWS...")
         checkNEWS(package_dir)
     }
 
-    if (is.null(dots[["no-check-unit-tests"]])){
+    if (.isNULLorFALSE(dots[["no-check-unit-tests"]])){
         handleCheck("Checking unit tests...")
         checkUnitTests(package_dir)
     }
 
-    if (is.null(dots[["no-check-skip-bioc-tests"]])){
+    if (.isNULLorFALSE(dots[["no-check-skip-bioc-tests"]])){
         handleCheck("Checking skip_on_bioc() in tests...")
         checkSkipOnBioc(package_dir)
     }
 
-    if (is.null(dots[["no-check-formatting"]])){
+    if (.isNULLorFALSE(dots[["no-check-formatting"]])){
         handleCheck(
             "Checking formatting of DESCRIPTION, NAMESPACE, ",
             "man pages, R source, and vignette source...")
         checkFormatting(.BiocPackage)
     }
 
-    if (is.null(dots[["no-check-CRAN"]]))
+    if (.isNULLorFALSE(dots[["no-check-CRAN"]]))
     {
         handleCheck("Checking if package already exists in CRAN...")
         checkIsPackageNameAlreadyInUse(package_name, "CRAN")
     }
 
-    if (!is.null(dots[["new-package"]]))
+    if (isTRUE(dots[["new-package"]]))
     {
         handleCheck("Checking if new package already exists in Bioconductor...")
         checkIsPackageNameAlreadyInUse(package_name, "BioCsoft")
@@ -332,7 +380,7 @@ BiocCheckRun <-
         # checkIsPackageNameAlreadyInUse(package_name, "BioCbooks")
     }
 
-    if (is.null(dots[["no-check-bioc-help"]])) {
+    if (.isNULLorFALSE(dots[["no-check-bioc-help"]])) {
         handleCheck("Checking for bioc-devel mailing list subscription...")
         if (hasAdmin) {
             checkForBiocDevelSubscription(.BiocPackage)
